{ config, pkgs, lib, ... }:

{
  imports = [
    ./bootstrap.nix
    ./homebrew.nix
    ./macos-defaults.nix
  ];

  # Apps
  # `home-manager` currently has issues adding them to `~/Applications`
  # Issue: https://github.com/nix-community/home-manager/issues/1341
  environment.systemPackages = with pkgs; [
    discord-ptb
    element-desktop
    # firefox *
    kitty
    lagrange
    # mullvad-vpn *
    obsidian
    # signal-desktop *
    slack
    # steam *
    terminal-notifier
    # zoom-us *
    # *no nixpkgs darwin support T.T
  ];

  # https://github.com/nix-community/home-manager/issues/423
  environment.variables = {
    TERMINFO_DIRS = "${pkgs.kitty.terminfo.outPath}/share/terminfo";
  };
  programs.nix-index.enable = true;

  environment.shells = with pkgs; [
    bashInteractive
    fish
    zsh
  ];
  # Fonts
  fonts.fontDir.enable = true;
  fonts.fonts = with pkgs; [
    recursive
    (nerdfonts.override {
      fonts = [
        "FantasqueSansMono"
        "JetBrainsMono"
        "FiraCode"
        "SourceCodePro"
      ];
    })
  ];

  # Keyboard
  # system.keyboard.enableKeyMapping = true;
  # system.keyboard.remapCapsLockToEscape = true;

  # Add ability to used TouchID for sudo authentication
  security.pam.enableSudoTouchIdAuth = true;

}
