{ pkgs, lib, ... }:
let statusCmd = "i3status-rs ~/.config/i3status.toml";
in {
  home = {
    sessionVariables = {
      BROWSER = "vivaldi";
      CM_LAUNCHER = "rofi";
    };
    packages = with pkgs; [
      # command line utilities
      asuka
      bottom
      dbus
      du-dust
      imagemagick
      mdcat
      pijul
      unrar
      wireguard-tools
      # graphical applications
      deluge
      discord
      dunst
      element-desktop
      enpass
      lagrange
      # mullvad-vpn
      okular
      signal-desktop
      slack
      steam
      steam-run-native
      vivaldi
      vivaldi-ffmpeg-codecs
      # vivaldi-widevine
      vlc
      xfce.thunar
      xfce.thunar-archive-plugin
      # graphical utilities
      clipmenu
      clipnotify
      gnome3.gnome-disk-utility
      i3status-rust
      libappindicator
      libnotify
      lxappearance
      rofi
      xclip
      xdg-dbus-proxy
    ];
    file = import ../hm-configs/files.nix;
  };
  programs = {
    alacritty = {
      enable = false;
      settings = {
        font = {
          normal.family = "Fira Code";
          size = 10.5;
        };
      };
    };
    command-not-found = { enable = true; };
    feh.enable = true;
    firefox.enable = false;
    fish = import ../hm-configs/fish.nix { inherit pkgs; };

    go.enable = false;
    jq.enable = true;
    keychain = {
      enable = true;
      extraFlags = [ "--quiet" "--nogui" ];
      enableFishIntegration = true;
      enableXsessionIntegration = false;
    };
    rofi = {
      enable = true;
      font = "Fira Code 14";
      lines = 10;
      location = "center";
      theme = "~/.config/rofi/theme.rasi";
    };
    ssh = {
      enable = true;
      matchBlocks = {
        "pi".hostname = "192.168.1.99";
        "gagarin" = {
          hostname = "gagarin.local";
          forwardAgent = true;
        };
        "soviet".hostname = "soviet.circumlunar.space";
      };
    };
    vscode = import ../hm-configs/vscode.nix { inherit pkgs; };
  };
  services = {
    redshift = {
      enable = true;
      provider = "geoclue2";
    };
    dunst = import ../hm-configs/dunst.nix;
    clipmenu.enable = true;
    # disabled in favor of flakes
    lorri.enable = false;
  };
  xdg = { mime.enable = true; };
  xsession = {
    enable = true;
    scriptPath = ".hm-xsession";
    windowManager = {
      i3 = import ../hm-configs/i3.nix { inherit lib statusCmd; };
      awesome = { enable = false; };
    };
  };
}
