# Colors from: https://ethanschoonover.com/solarized

# SOLARIZED HEX     16/8 TERMCOL  XTERM/HEX   L*A*B      RGB         HSB
# --------- ------- ---- -------  ----------- ---------- ----------- -----------
# base03    #002b36  8/4 brblack  234 #1c1c1c 15 -12 -12   0  43  54 193 100  21
# base02    #073642  0/4 black    235 #262626 20 -12 -12   7  54  66 192  90  26
# base01    #586e75 10/7 brgreen  240 #585858 45 -07 -07  88 110 117 194  25  46
# base00    #657b83 11/7 bryellow 241 #626262 50 -07 -07 101 123 131 195  23  51
# base0     #839496 12/6 brblue   244 #808080 60 -06 -03 131 148 150 186  13  59
# base1     #93a1a1 14/4 brcyan   245 #8a8a8a 65 -05 -02 147 161 161 180   9  63
# base2     #eee8d5  7/7 white    254 #e4e4e4 92 -00  10 238 232 213  44  11  93
# base3     #fdf6e3 15/7 brwhite  230 #ffffd7 97  00  10 253 246 227  44  10  99
# yellow    #b58900  3/3 yellow   136 #af8700 60  10  65 181 137   0  45 100  71
# orange    #cb4b16  9/3 brred    166 #d75f00 50  50  55 203  75  22  18  89  80
# red       #dc322f  1/1 red      160 #d70000 50  65  45 220  50  47   1  79  86
# magenta   #d33682  5/5 magenta  125 #af005f 50  65 -05 211  54 130 331  74  83
# violet    #6c71c4 13/5 brmagenta 61 #5f5faf 50  15 -45 108 113 196 237  45  77
# blue      #268bd2  4/4 blue      33 #0087ff 55 -10 -45  38 139 210 205  82  82
# cyan      #2aa198  6/6 cyan      37 #00afaf 60 -35 -05  42 161 152 175  74  63
# green     #859900  2/2 green     64 #5f8700 60 -20  65 133 153   0  68 100  60

rec {
  colors = {
    darkBase = "002b36"; # base03
    darkBasehl = "073642"; # base02
    darkestTone = "586e75"; # base01
    darkTone = "657b83"; # base00
    lightTone = "839496"; # base0
    lightestTone = "93a1a1"; # base1
    lightBasehl = "eee8d5"; # base2
    lightBase = "fdf6e3"; # base3
    yellow = "b58900";
    orange = "cb4b16";
    red = "dc322f";
    magenta = "d33682";
    violet = "6c71c4";
    blue = "268bd2";
    cyan = "2aa198";
    green = "859900";
  };

  _light = with colors; {
    base = lightBase;
    basehl = lightBasehl;
    invbase = darkBase;
    invbasehl = darkBasehl;
    main = darkTone;
    faded = lightTone;
    muted = lightestTone;
    strong = darkestTone;
    inherit (colors) yellow orange red megenta violet blue cyan green;
  };

  _dark = with colors; {
    base = darkBase;
    basehl = darkBasehl;
    invbase = lightBase;
    invbasehl = lightBasehl;
    main = lightTone;
    faded = darkTone;
    muted = darkestTone;
    strong = lightestTone;
    inherit (colors) yellow orange red megenta violet blue cyan green;
  };

  backgroundDependentColors = colors: with colors; {
    background = "#${base}";
    foreground = "#${main}";

    # Cursor
    cursor = "#${blue}";
    cursor_text_color = "#${base}";

    # Selection
    selection_background = "#${muted}";
    selection_foreground = "#${base}";

    # Tab bar
    tab_bar_background = "#${basehl}";
    inactive_tab_background = "#${strong}";
  };

  dark = backgroundDependentColors _dark;
  light = backgroundDependentColors _light;

  common = with colors; {
    # black
    color0 = "#${darkBasehl}";
    color8 = "#${darkBase}";
    # red
    color1 = "#${red}";
    color9 = "#${orange}";
    # green
    color2 = "#${green}";
    color10 = "#${darkestTone}";
    # yellow
    color3 = "#${yellow}";
    color11 = "#${darkTone}";
    # blue
    color4 = "#${blue}";
    color12 = "#${lightTone}";
    # magenta
    color5 = "#${magenta}";
    color13 = "#${violet}";
    # cyan
    color6 = "#${cyan}";
    color14 = "#${lightestTone}";
    # white
    color7 = "#${lightBasehl}";
    color15 = "#${lightBase}";
    # url underline color to fit colors
    url_color = "#${blue}";
    # tab bar
    active_tab_foreground = "#${lightBase}";
    active_tab_background = "#${green}";
    inactive_tab_foreground = "#${lightBase}";
  };
}
